==> SexyMap-v7.3.3.zip: SexyMap/localization/esES.lua <==

if GetLocale() ~= "esES" and GetLocale() ~= "esMX" then return end
local _, sm = ...
local L = sm.L
L["1. Background"] = "Fondo"
L["2. Border"] = "Borde"
L["3. Artwork"] = "Arte"
L["4. Overlay"] = "Superposición"
L["5. Highlight"] = "Resaltar"
L["Add Blend (additive)"] = "Agregar Mezcla (aditivo)"
L["Addon Buttons"] = "Botones del Addon"
L["A global profile already exists. You will be switched over to it and your UI will be reloaded, are you sure?"] = "Ya existe un perfil global. Éste se activará y tu UI será reiniciada. Estás seguro?"
L["Allow SexyMap to assume drag ownership for buttons attached to the minimap. Turn this off if you have another mod that you want to use to position your minimap buttons."] = "Permitir a SexyMap asumir control del arrastre de los botones junto al minimapa. Desactivalo si tienes otro mod que quieres usar para posicionar los botones del minimapa."
L["Alpha Key (1-bit alpha)"] = "Alfa Key (1-bit alpha)"
L["Always"] = "Siempre"
-- L["Are you sure you want to switch back to using a character specific profile? This will reload your UI."] = "Are you sure you want to switch back to using a character specific profile? This will reload your UI."
L["Armored Man"] = "Hombre Acorazado"
L["A static amount to rotate the texture by."] = "Una cantidad fija para girar la textura."
L["Auto Zoom-Out Delay"] = "Retraso del alejamiento automático"
L["Backdrop Color"] = "Color del Telón"
L["Backdrop Insets"] = "Añadidos al Telón"
L["Background Color"] = "Color del Fondo"
L["Background/edge"] = "Fondo/borde"
L["Background Texture"] = "Textura del Fondo"
L["Blend Mode"] = "Modo Mezcla"
L["Blend (normal)"] = "Mezclar (normal)"
L["Border Color"] = "Color del Borde"
L["Border Edge Size"] = "Tamaño del límite del borde"
L["Borders"] = "Bordes"
L["Border Texture"] = "Textura del Borde"
L["Boss Frames"] = "Retrato del Jefe"
L["Buttons"] = "Botones"
L["Calendar"] = "Calendario"
L["Capture Bars"] = "Capturar Barras"
L["Challenge Mode Button (When Available)"] = "Botón de Modo Desafío (cuando está disponible)"
L["Circle"] = "Círculo"
L["Clamp to screen"] = "Fijar a la pantalla"
L["Clear & start over"] = "Borrar y empezar de nuevo"
L["Clear the current borders and start fresh"] = "Borrar los bordes actuales y comenzar de nuevo"
L["Clock"] = "Reloj"
L["Coordinates"] = "Coordenadas"
L["Copy a Profile"] = "Copiar un Perfil"
-- L["Copying this profile will reload your UI, are you sure?"] = "Copying this profile will reload your UI, are you sure?"
L["Create a new border"] = "Crear un borde nuevo"
L["Current Borders"] = "Bordes actuales"
L["Default Presets"] = "Preconfiguración por defecto"
L["Delete"] = "Eliminar"
L["Delete a Profile"] = "Borrar un Perfil"
L["Diamond"] = "Diamante"
L["Disable (opaque)"] = "Desactivar (opaco)"
L["Disable Rotation"] = "Desactivar la rotación"
-- L["Disabling the movers will make them reset next time you relog, are you sure?"] = "Disabling the movers will make them reset next time you relog, are you sure?"
L["Drag Radius"] = "Radio de Arrastre"
L["Dungeon Difficulty Indicator (When Available)"] = "Indicador de Dificultad de Mazmorra (Cuando esté disponible)"
L["Dynamic Buttons"] = "Botones dinámicos"
L["Enable"] = "Habilitar"
-- L["Enable a backdrop and border for the minimap. This will let you set square borders more easily."] = "Enable a backdrop and border for the minimap. This will let you set square borders more easily."
-- L["Enable a HUD minimap. This is very useful for gathering resources, but for technical reasons, the HUD map and the normal minimap can't be shown at the same time. Showing the HUD map will turn off the normal minimap."] = "Enable a HUD minimap. This is very useful for gathering resources, but for technical reasons, the HUD map and the normal minimap can't be shown at the same time. Showing the HUD map will turn off the normal minimap."
L["Enable Coordinates"] = "Habilitar Coordenadas"
L["Enable Hudmap"] = "Habilitar el Hudmap"
L["Enable Minimap Fader"] = "Habilitar desvanecimiento del minimapa"
-- L["Enable Movers"] = "Enable Movers"
L["Enter a name to create a new border. The name can be anything you like to help you identify that border."] = "Entre un nombre para crear un nuevo borde. El nombre puede ser cualquiera que te ayude a identificar ese borde."
-- L["Enter the full path to a texture to use. It's recommended that you use something like |cffff6600TexBrowser|r to find textures to use."] = "Enter the full path to a texture to use. It's recommended that you use something like |cffff6600TexBrowser|r to find textures to use."
L["Entry Options"] = " Opciones de entrada"
L["Faded Circle (Large)"] = "Círculo de desvanecimiento (grande)"
L["Faded Circle (Small)"] = "Circulo difuminado (Pequeño)"
L["Faded Square"] = "Cuadrado difuminado"
L["Fader"] = "Desvanecedor"
L["Font"] = "Fuente"
L["Font Color"] = "Color de la fuente"
L["Font Size"] = "Tamaño de Fuente"
-- L["Force a square texture. Fixed distortion on square textures."] = "Force a square texture. Fixed distortion on square textures."
-- L["Garrison Button (When Available)"] = "Garrison Button (When Available)"
L["Guild Dungeon Difficulty Indicator (When Available)"] = "Indicador de dificultad de calabozo de clan (Mientras este disponible)"
L["Heart"] = "Corazón"
L["Height"] = "Alto"
L["Hexagon"] = "Hexágono"
L["Hide default border"] = "Ocultar borde por defecto"
L["Hide the default border on the minimap."] = "Ocultar el borde por defecto en el minimapa"
-- L["Horizontal Nudge"] = "Horizontal Nudge"
L["Horizontal Position"] = "Posición Horizontal"
-- L["Hover Opacity"] = "Hover Opacity"
L["HUD Color"] = "Color del HUD"
-- L["If you zoom into the map, this feature will automatically zoom out after the selected period of time (seconds). Using a value of 0 will disable Auto Zoom-Out."] = "If you zoom into the map, this feature will automatically zoom out after the selected period of time (seconds). Using a value of 0 will disable Auto Zoom-Out."
-- L["Keybinding"] = "Keybinding"
L["Layer"] = "Capa"
L["Let SexyMap control button visibility"] = "Dejar que SexyMap controle la visivilidad de los botones"
-- L["Let SexyMap handle button dragging"] = "Let SexyMap handle button dragging"
L["Lock Button Dragging"] = "Anclar arrastre de boton"
L["Lock Coordinates"] = "Bloquear Coordenadas"
L["Lock Minimap"] = "Bloquear Minimapa"
-- L["Lock Movers"] = "Lock Movers"
L["Map Button"] = "Botón del Mapa"
L["Minimap shape"] = "Forma del minimapa"
-- L["Mod Blend (modulative)"] = "Mod Blend (modulative)"
-- L["Movers"] = "Movers"
-- L["Movers Warning"] = "WARNING: This feature is not officially supported, expect problems when using this feature such as taints, loss of quest tracker functionality, or boss frames jumping around. Blizzard frames like the quest tracker and boss health aren't designed to be moved, I suggest you use addons that replace these frames e.g. Unit Frames for boss health."
L["Name"] = "Nombre"
L["Never"] = "Nunca"
L["New Mail Indicator (When Available)"] = "Indicador de correo nuevo (cuando esté disponible)"
-- L["No global profile exists. Your current profile will be copied over and used as the global profile, are you sure? This will also reload your UI."] = "No global profile exists. Your current profile will be copied over and used as the global profile, are you sure? This will also reload your UI."
L["Normal Opacity"] = "Opacidad Normal"
L["Objectives Tracker"] = "Rastreador de objetivos"
L["Octagon"] = "Octágono"
-- L["On Hover"] = "On Hover"
L["Opacity"] = "Opacidad"
-- L["Open TexBrowser"] = "Open TexBrowser"
L["Ping"] = "Ping"
L["Preset"] = "Preconfiguración"
L["Prevent the minimap from being moved off the screen"] = "Prevenir que el minimapa sea movido fuera de la pantalla"
L["Profiles"] = "Perfiles"
-- L["Queue Status (PvP/LFG) Button (When Available)"] = "Queue Status (PvP/LFG) Button (When Available)"
-- L["Quickly change the look of your minimap by using a minimap preset."] = "Quickly change the look of your minimap by using a minimap preset."
L["Really delete this border?"] = "¿Realmente quiere borrar este borde?"
L["Really delete this preset? This can't be undone."] = "¿Estás seguro de que quieres borrar esta preconfiguración? No se puede deshacer esta acción."
L["Really delete this profile?"] = "¿De verdad quieres borrar este perfil?"
-- L["(Requires button visibility control in the Buttons menu)"] = "(Requires button visibility control in the Buttons menu)"
L["Reset Current Profile"] = "Reiniciar perfil actual"
L["Reset Position"] = "Restaurar posición"
-- L["Resetting this profile will reload your UI, are you sure?"] = "Resetting this profile will reload your UI, are you sure?"
L["Right Click Configure"] = "Configurar Click Derecho"
L["Right clicking the map will open the SexyMap options"] = "Haciendo click derecho en el mapa se abrirán las opciones de SexyMap"
L["Rotation Speed (seconds)"] = "Velocidad de Rotación (segundos)"
L["Rounded - Bottom Left"] = "Redondeado - Inferior izquierdo"
L["Rounded - Bottom Right"] = "Redondeado - Inferior derecho"
L["Rounded - Top Left"] = "Redondeado - Superior izquierdo"
L["Rounded - Top Right"] = "Redondeado - Superior derecho"
L["Route 66"] = "Ruta 66"
L["Save current settings as preset..."] = "Guardar configuración actual como predeterminada..."
L["Scale"] = "Escala"
L["Select a preset to load settings from. This will erase any of your current borders."] = "Seleccione un preset de donde cargar la configuracion. Esto borrara todos los bordes actuales"
L["Select preset to load"] = "Selecciona la preconfiguración que quieras cargar"
-- L["SharedMedia Border"] = "SharedMedia Border"
-- L["SharedMedia Texture"] = "SharedMedia Texture"
L["Show inside chat"] = "Mostrar chat interior"
-- L["Show North Tag"] = "Show North Tag"
L["Show on minimap"] = "Mostrar en el minimapa"
L["Show %s:"] = "Mostrar %s"
L["Show who pinged"] = "Mostrar quien ha pinchado"
L["Snowflake"] = "Copo de nieve"
L["Spice up your minimap with some sexy options."] = "Condimenta tu minimapa con unas cuantas opciones sexys."
L["Square"] = "Quadrado"
L["Standard Buttons"] = "Botones Estandar"
L["Static Rotation"] = "Rotación estática"
-- L["TexBrowser Not Installed"] = "TexBrowser Not Installed"
L["Text Color"] = "Color del Texto"
L["Texture"] = "Textura"
L["Texture Options"] = "Opciones de Textura"
L["Texture Path"] = "Directorio de textura"
L["Texture Tint"] = "Tintura de textura"
L["Text Width"] = "Anchura del texto"
-- L["The HudMap supports several addons. If you have any of the addons below installed, they will be shown on the HudMap."] = "The HudMap supports several addons. If you have any of the addons below installed, they will be shown on the HudMap."
L["The time it takes (in seconds) to complete one rotation. A setting of 0 turns off rotation."] = "El tiempo que tardará (en segundos) en dar una vuelta completa. Marcar 0 deshabilitará la rotación"
L["This will wipe out any current settings!"] = "Esto borrara todas las configuraciones actuales!"
-- L["Tile Background"] = "Tile Background"
-- L["Tile Size"] = "Tile Size"
-- L["Toggle HudMap On/Off"] = "Toggle HudMap On/Off"
-- L["Tracking Button"] = "Tracking Button"
-- L["Turn this off if you want another mod to handle which buttons are visible on the minimap."] = "Turn this off if you want another mod to handle which buttons are visible on the minimap."
L["Use Global Profile"] = "Usar el Perfil Global"
-- L["User-Submitted Presets"] = "User-Submitted Presets"
-- L["Use the global profile if you want the same look on every character, or use a character-specific profile for a unique look on each character."] = "Use the global profile if you want the same look on every character, or use a character-specific profile for a unique look on each character."
-- L["Vehicle Seat"] = "Vehicle Seat"
-- L["Vertical Nudge"] = "Vertical Nudge"
-- L["Vertical Position"] = "Vertical Position"
L["Visibility"] = "Visibilidad"
L["Voice Chat Button (When Available)"] = "Botón del chat de voz (cuando esté disponible)"
L["Width"] = "Ancho"
-- L["You can set a background and edge file for the minimap like you would with any frame. This is useful when you want to create static square backdrops for your minimap."] = "You can set a background and edge file for the minimap like you would with any frame. This is useful when you want to create static square backdrops for your minimap."
-- L["Zone Text"] = "Zone Text"
L["Zoom In Button"] = "Botón de Acercar Zoom"
L["Zoom Out Button"] = "Botón de Alejar Zoom"

--L.updateRate = "Update Rate (seconds)"
--L.updateRateDesc = "The lower the value, the faster the coordinates will update, but the more memory and CPU will be consumed due to asking the game for fresh coordinate data."

==> SexyMap-v8.3.0.zip: SexyMap/localization/esES.lua <==

if GetLocale() ~= "esES" and GetLocale() ~= "esMX" then return end
local _, sm = ...
local L = sm.L
L["1. Background"] = "Fondo"
L["2. Border"] = "Borde"
L["3. Artwork"] = "Arte"
L["4. Overlay"] = "Superposición"
L["5. Highlight"] = "Resaltar"
L["Add Blend (additive)"] = "Agregar Mezcla (aditivo)"
L["Addon Buttons"] = "Botones del Addon"
L["A global profile already exists. You will be switched over to it and your UI will be reloaded, are you sure?"] = "Ya existe un perfil global. Éste se activará y tu UI será reiniciada. Estás seguro?"
L["Allow SexyMap to assume drag ownership for buttons attached to the minimap. Turn this off if you have another mod that you want to use to position your minimap buttons."] = "Permitir a SexyMap asumir control del arrastre de los botones junto al minimapa. Desactivalo si tienes otro mod que quieres usar para posicionar los botones del minimapa."
L["Alpha Key (1-bit alpha)"] = "Alfa Key (1-bit alpha)"
L["Always"] = "Siempre"
L["Are you sure you want to switch back to using a character specific profile? This will reload your UI."] = "¿Estás seguro de que quieres volver a utilizar un perfil específico de un personaje? Esto recargará tu interfaz."
L["Armored Man"] = "Hombre Acorazado"
L["A static amount to rotate the texture by."] = "Una cantidad fija para girar la textura."
L["Auto Zoom-Out Delay"] = "Retraso del alejamiento automático"
L["Backdrop Color"] = "Color del Telón"
L["Backdrop Insets"] = "Añadidos al Telón"
L["Background Color"] = "Color del Fondo"
L["Background/edge"] = "Fondo/borde"
L["Background Texture"] = "Textura del Fondo"
L["Blend Mode"] = "Modo Mezcla"
L["Blend (normal)"] = "Mezclar (normal)"
L["Border Color"] = "Color del Borde"
L["Border Edge Size"] = "Tamaño del límite del borde"
L["Borders"] = "Bordes"
L["Border Texture"] = "Textura del Borde"
L["Boss Frames"] = "Retrato del Jefe"
L["Buttons"] = "Botones"
L["Calendar"] = "Calendario"
L["Capture Bars"] = "Capturar Barras"
L["Challenge Mode Button (When Available)"] = "Botón de Modo Desafío (cuando está disponible)"
L["Circle"] = "Círculo"
L["Clamp to screen"] = "Fijar a la pantalla"
L["Clear & start over"] = "Borrar y empezar de nuevo"
L["Clear the current borders and start fresh"] = "Borrar los bordes actuales y comenzar de nuevo"
L["Clock"] = "Reloj"
L["Coordinates"] = "Coordenadas"
L["Copy a Profile"] = "Copiar un Perfil"
L["Copying this profile will reload your UI, are you sure?"] = "Copiar este perfil recargará tu interfaz, ¿estás seguro?"
L["Create a new border"] = "Crear un borde nuevo"
L["Current Borders"] = "Bordes actuales"
L["Default Presets"] = "Preconfiguración por defecto"
L["Delete"] = "Eliminar"
L["Delete a Profile"] = "Borrar un Perfil"
L["Diamond"] = "Diamante"
L["Disable (opaque)"] = "Desactivar (opaco)"
L["Disable Rotation"] = "Desactivar la rotación"
-- L["Disabling the movers will make them reset next time you relog, are you sure?"] = "Disabling the movers will make them reset next time you relog, are you sure?"
L["Drag Radius"] = "Radio de Arrastre"
L["Dungeon Difficulty Indicator (When Available)"] = "Indicador de Dificultad de Mazmorra (Cuando esté disponible)"
L["Dynamic Buttons"] = "Botones dinámicos"
L["Enable"] = "Habilitar"
L["Enable a backdrop and border for the minimap. This will let you set square borders more easily."] = "Activar un fondo y un borde para el minimapa. Esto te permitirá establecer un borde cuadrado más fácilmente."
L["Enable a HUD minimap. This is very useful for gathering resources, but for technical reasons, the HUD map and the normal minimap can't be shown at the same time. Showing the HUD map will turn off the normal minimap."] = "Habilitar un minimapa tipo HUD. Esto es muy útil para recolectar recursos, pero por razones técnicas, el mapa tipo HUD y el minimapa normal no se pueden mostrar al mismo tiempo. Al mostrar el mapa tipo HUD se desactivará el minimapa normal."
L["Enable Coordinates"] = "Habilitar Coordenadas"
L["Enable Hudmap"] = "Habilitar el Hudmap"
L["Enable Minimap Fader"] = "Habilitar desvanecimiento del minimapa"
-- L["Enable Movers"] = "Enable Movers"
L["Enter a name to create a new border. The name can be anything you like to help you identify that border."] = "Entre un nombre para crear un nuevo borde. El nombre puede ser cualquiera que te ayude a identificar ese borde."
-- L["Enter the full path to a texture to use. It's recommended that you use something like |cffff6600TexBrowser|r to find textures to use."] = "Enter the full path to a texture to use. It's recommended that you use something like |cffff6600TexBrowser|r to find textures to use."
L["Entry Options"] = " Opciones de entrada"
L["Faded Circle (Large)"] = "Círculo de desvanecimiento (grande)"
L["Faded Circle (Small)"] = "Circulo difuminado (Pequeño)"
L["Faded Square"] = "Cuadrado difuminado"
L["Fader"] = "Desvanecedor"
L["Font"] = "Fuente"
L["Font Color"] = "Color de la fuente"
L["Font Size"] = "Tamaño de Fuente"
-- L["Force a square texture. Fixed distortion on square textures."] = "Force a square texture. Fixed distortion on square textures."
-- L["Garrison Button (When Available)"] = "Garrison Button (When Available)"
L["Guild Dungeon Difficulty Indicator (When Available)"] = "Indicador de dificultad de mazmorra de hermadad (cuando esté disponible)"
L["Heart"] = "Corazón"
L["Height"] = "Alto"
L["Hexagon"] = "Hexágono"
L["Hide default border"] = "Ocultar borde por defecto"
L["Hide the default border on the minimap."] = "Ocultar el borde por defecto en el minimapa"
-- L["Horizontal Nudge"] = "Horizontal Nudge"
L["Horizontal Position"] = "Posición Horizontal"
L["Hover Opacity"] = "Opacidad al pasar el ratón por encima"
L["HUD Color"] = "Color del HUD"
L["If you zoom into the map, this feature will automatically zoom out after the selected period of time (seconds). Using a value of 0 will disable Auto Zoom-Out."] = "Si haces zoom en el mapa, esta característica alejará automáticamente el zoom después del período de tiempo seleccionado (segundos). Usando un valor de 0 se desactivará la función de alejamiento automático del zoom."
L["Keybinding"] = "Asignación de teclas"
L["Layer"] = "Capa"
L["Let SexyMap control button visibility"] = "Dejar que SexyMap controle la visivilidad de los botones"
-- L["Let SexyMap handle button dragging"] = "Let SexyMap handle button dragging"
L["Lock Button Dragging"] = "Anclar arrastre de boton"
L["Lock Minimap"] = "Bloquear Minimapa"
-- L["Lock Movers"] = "Lock Movers"
L["Map Button"] = "Botón del Mapa"
L["Minimap shape"] = "Forma del minimapa"
-- L["Mod Blend (modulative)"] = "Mod Blend (modulative)"
-- L["Movers"] = "Movers"
-- L["Movers Warning"] = "WARNING: This feature is not officially supported, expect problems when using this feature such as taints, loss of quest tracker functionality, or boss frames jumping around. Blizzard frames like the quest tracker and boss health aren't designed to be moved, I suggest you use addons that replace these frames e.g. Unit Frames for boss health."
L["Name"] = "Nombre"
L["Never"] = "Nunca"
L["New Mail Indicator (When Available)"] = "Indicador de correo nuevo (cuando esté disponible)"
-- L["No global profile exists. Your current profile will be copied over and used as the global profile, are you sure? This will also reload your UI."] = "No global profile exists. Your current profile will be copied over and used as the global profile, are you sure? This will also reload your UI."
L["Normal Opacity"] = "Opacidad Normal"
L["Objectives Tracker"] = "Rastreador de objetivos"
L["Octagon"] = "Octágono"
L["On Hover"] = "Al pasar por encima el ratón"
L["Opacity"] = "Opacidad"
-- L["Open TexBrowser"] = "Open TexBrowser"
L["Ping"] = "Ping"
L["Preset"] = "Preconfiguración"
L["Prevent the minimap from being moved off the screen"] = "Prevenir que el minimapa sea movido fuera de la pantalla"
L["Profiles"] = "Perfiles"
-- L["Queue Status (PvP/LFG) Button (When Available)"] = "Queue Status (PvP/LFG) Button (When Available)"
-- L["Quickly change the look of your minimap by using a minimap preset."] = "Quickly change the look of your minimap by using a minimap preset."
L["Really delete this border?"] = "¿Realmente quiere borrar este borde?"
L["Really delete this preset? This can't be undone."] = "¿Estás seguro de que quieres borrar esta preconfiguración? No se puede deshacer esta acción."
L["Really delete this profile?"] = "¿De verdad quieres borrar este perfil?"
-- L["(Requires button visibility control in the Buttons menu)"] = "(Requires button visibility control in the Buttons menu)"
L["Reset Current Profile"] = "Reiniciar perfil actual"
L["Resetting this profile will reload your UI, are you sure?"] = "Restablecer este perfil recargará tu interfaz de usuario, ¿estás seguro?"
L["Right Click Configure"] = "Configurar clic derecho"
L["Right clicking the map will open the SexyMap options"] = "Haciendo clic derecho en el mapa se abrirán las opciones de SexyMap"
L["Rotation Speed (seconds)"] = "Velocidad de Rotación (segundos)"
L["Rounded - Bottom"] = "Redondeado - Inferior"
L["Rounded - Bottom Left"] = "Redondeado - Inferior izquierdo"
L["Rounded - Bottom Right"] = "Redondeado - Inferior derecho"
L["Rounded - Left"] = "Redondeado - izquierdo"
L["Rounded - Right"] = "Redondeado - derecho"
L["Rounded - Top"] = "Redondeado - Superior"
L["Rounded - Top Left"] = "Redondeado - Superior izquierdo"
L["Rounded - Top Right"] = "Redondeado - Superior derecho"
L["Route 66"] = "Ruta 66"
L["Save current settings as preset..."] = "Guardar configuración actual como predeterminada..."
L["Scale"] = "Escala"
L["Select a preset to load settings from. This will erase any of your current borders."] = "Seleccione un preset de donde cargar la configuracion. Esto borrara todos los bordes actuales"
L["Select preset to load"] = "Selecciona la preconfiguración que quieras cargar"
-- L["SharedMedia Border"] = "SharedMedia Border"
-- L["SharedMedia Texture"] = "SharedMedia Texture"
L["Show inside chat"] = "Mostrar chat interior"
L["Show North Tag"] = "Mostrar etiqueta en el norte"
L["Show on minimap"] = "Mostrar en el minimapa"
L["Show %s:"] = "Mostrar %s"
L["Show who pinged"] = "Mostrar quien ha pinchado"
L["Snowflake"] = "Copo de nieve"
L["Spice up your minimap with some sexy options."] = "Condimenta tu minimapa con unas cuantas opciones sexys."
L["Square"] = "Quadrado"
L["Standard Buttons"] = "Botones Estandar"
L["Static Rotation"] = "Rotación estática"
-- L["TexBrowser Not Installed"] = "TexBrowser Not Installed"
L["Text Color"] = "Color del Texto"
L["Texture"] = "Textura"
L["Texture Options"] = "Opciones de Textura"
L["Texture Path"] = "Directorio de textura"
L["Texture Tint"] = "Tintura de textura"
L["Text Width"] = "Anchura del texto"
-- L["The HudMap supports several addons. If you have any of the addons below installed, they will be shown on the HudMap."] = "The HudMap supports several addons. If you have any of the addons below installed, they will be shown on the HudMap."
L["The time it takes (in seconds) to complete one rotation. A setting of 0 turns off rotation."] = "El tiempo que tardará (en segundos) en dar una vuelta completa. Marcar 0 deshabilitará la rotación"
L["This will wipe out any current settings!"] = "Esto borrara todas las configuraciones actuales!"
-- L["Tile Background"] = "Tile Background"
-- L["Tile Size"] = "Tile Size"
-- L["Toggle HudMap On/Off"] = "Toggle HudMap On/Off"
L["Tracking Button"] = "Botón de rastreo"
-- L["Turn this off if you want another mod to handle which buttons are visible on the minimap."] = "Turn this off if you want another mod to handle which buttons are visible on the minimap."
L["Use Global Profile"] = "Usar el Perfil Global"
-- L["User-Submitted Presets"] = "User-Submitted Presets"
L["Use the global profile if you want the same look on every character, or use a character-specific profile for a unique look on each character."] = "Usa el perfil global si quieres el mismo aspecto en todos los personajes, o utiliza un perfil específico para cada personaje."
L["Vehicle Seat"] = "Asiento de vehículo"
-- L["Vertical Nudge"] = "Vertical Nudge"
L["Vertical Position"] = "Posición vertical"
L["Visibility"] = "Visibilidad"
L["Width"] = "Ancho"
L["You can set a background and edge file for the minimap like you would with any frame. This is useful when you want to create static square backdrops for your minimap."] = "Puedes establecer un archivo de fondo y de borde para el minimapa como lo harías con cualquier marco. Esto es útil cuando quieres crear fondos cuadrados estáticos para tu minimapa."
L["Zone Text"] = "Texto de zona"
L["Zoom In Button"] = "Botón de Acercar Zoom"
L["Zoom Out Button"] = "Botón de Alejar Zoom"

L.updateRate = "Frecuencia de actualización (segundos)"
L.updateRateDesc = "Cuanto más bajo sea el valor, más rápido se actualizarán las coordenadas, pero más memoria y CPU se consumirán debido a que se le pedirá al juego datos de coordenadas nuevos."
